@@ -16,10 +16,14 @@ class OwncloudControl:
         self.insider = insider
         self.access = access
 
-    def finish(self, login, password, host):
+    def finish(self, login, password, host, protocol):
         owncloud_url = 'http://{}:{}/{}'.format(host, self.config.port_http, self.config.url)
         setup.finish(owncloud_url, login, password)
-        self.access.https_on()
+        protocol = protocol.to_lower()
+        if protocol == 'https':
+            self.access.https_on()
+        elif protocol != 'http':
+            raise Exception('Unknown protocol {}, it should either http or https'.format(protocol))
         self.config_manager.overwrite_webroot()
 
     def https_on(self):
